"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.angularInit = exports.addAngularPluginToViteConfig = void 0;
const devkit_1 = require("@nx/devkit");
const path = require("path");
const versions_1 = require("../versions");
const update_vite_config_1 = require("../update-vite-config");
const vite_1 = require("@nx/vite");
function addFiles(tree, options) {
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files', options.installMaterialExample ? 'material/integration-files' : 'demo'), options.demoFilePath, {});
    if (options.installMaterialExample && options.isApp) {
        const added = addRootStyles(tree, options);
        if (added) {
            (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files/material/styles'), (0, devkit_1.joinPathFragments)(options.projectRoot, 'src'), {});
        }
        else {
            devkit_1.output.warn({
                title: 'Failed to add material theme',
                bodyLines: [
                    "Your integration is still functional, however you'll need to add Angular Material theme manually",
                    // TODO: link to the docs
                ],
            });
        }
    }
}
function addRootStyles(tree, options) {
    const rootTsxPath = (0, devkit_1.joinPathFragments)(options.projectRoot, 'src/root.tsx');
    const importStatement = `import './theme.scss';`;
    if (tree.exists(rootTsxPath)) {
        let rootTsxContent = tree.read(rootTsxPath, 'utf-8');
        const indexToInsert = rootTsxContent.indexOf(`import './global.css';`);
        if (indexToInsert !== -1) {
            const before = rootTsxContent.slice(0, indexToInsert);
            const after = rootTsxContent.slice(indexToInsert);
            rootTsxContent = `${before}${importStatement}\n${after}`;
        }
        else {
            rootTsxContent = `${importStatement}\n${rootTsxContent}`;
        }
        tree.write(rootTsxPath, rootTsxContent);
        return true;
    }
    return false;
}
function addDependencies(tree, installMaterial) {
    const devDependencies = {
        '@angular/cdk': versions_1.angularVersion,
        '@angular/common': versions_1.angularVersion,
        '@analogjs/vite-plugin-angular': versions_1.vitePluginAngularVersion,
        '@qwikdev/qwik-angular': versions_1.qwikAngularVersion,
        '@angular-devkit/build-angular': versions_1.angularVersion,
        '@angular/compiler': versions_1.angularVersion,
        '@angular/compiler-cli': versions_1.angularVersion,
        '@angular/core': versions_1.angularVersion,
        '@angular/forms': versions_1.angularVersion,
        '@angular/platform-browser-dynamic': versions_1.angularVersion,
        '@angular/platform-browser': versions_1.angularVersion,
        '@angular/platform-server': versions_1.angularVersion,
        '@ngtools/webpack': versions_1.angularVersion,
    };
    if (installMaterial) {
        Object.assign(devDependencies, {
            '@angular/material': versions_1.angularVersion,
        });
    }
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, devDependencies);
}
function addAngularPluginToViteConfig(tree, options) {
    var _a;
    const viteConfigPath = (0, vite_1.normalizeViteConfigFilePathWithTree)(tree, options.projectRoot);
    if (!viteConfigPath) {
        throw new Error(`Could not resolve vite config at ${options.projectRoot}`);
    }
    const viteConfig = tree.read(viteConfigPath).toString();
    const bundleSassFilesInDevMode = `bundleSassFilesInDevMode: {
    paths: ["src/theme.scss"],
    compileOptions: { loadPaths: ["node_modules"] },
  }`;
    const updatedViteConfig = (0, update_vite_config_1.updateViteConfig)(viteConfig, {
        imports: [
            {
                namedImports: ['angular'],
                importPath: '@qwikdev/qwik-angular/vite',
            },
        ],
        vitePlugins: [
            `angular({
      tsconfig: "${(_a = getAppTsConfigFileName(tree, options)) !== null && _a !== void 0 ? _a : '<INSERT VALID PATH TO TSCONFIG HERE>'}",
      componentsDir: "integrations/angular/components",
      ${options.installMaterialExample ? bundleSassFilesInDevMode : ''}
    })`,
        ],
    });
    tree.write(viteConfigPath, updatedViteConfig);
}
exports.addAngularPluginToViteConfig = addAngularPluginToViteConfig;
function getAppTsConfigFileName(tree, options) {
    for (const tsConfigName of ['tsconfig.app.json', 'tsconfig.json']) {
        const tsConfigPath = (0, devkit_1.joinPathFragments)(options.projectRoot, tsConfigName);
        if (tree.exists(tsConfigPath)) {
            return tsConfigName;
        }
    }
    devkit_1.output.warn({
        title: `Could not resolve tsconfig at ${options.projectRoot}`,
        bodyLines: [
            'This means the Angular functionality may appear broken. In order to fix it, please add "noEmit": false" manually',
        ],
    });
    return null;
}
function updateTsConfig(tree, options) {
    const tsConfigFileName = getAppTsConfigFileName(tree, options);
    if (!tsConfigFileName) {
        return;
    }
    const tsConfig = (0, devkit_1.readJson)(tree, (0, devkit_1.joinPathFragments)(options.projectRoot, tsConfigFileName));
    tsConfig.compilerOptions.noEmit = false;
    tsConfig.compilerOptions.experimentalDecorators = true;
    tsConfig.angularCompilerOptions = {
        enableI18nLegacyMessageIdFormat: false,
        strictInjectionParameters: true,
        strictInputAccessModifiers: true,
        strictTemplates: true,
    };
    (0, devkit_1.writeJson)(tree, tsConfigFileName, tsConfig);
}
/**
 * - adds angular example component (either Material or plain angular one)
 * - installs necessary dependencies
 */
function angularInit(tree, options) {
    addFiles(tree, options);
    addAngularPluginToViteConfig(tree, options);
    updateTsConfig(tree, options);
    return addDependencies(tree, !!options.installMaterialExample);
}
exports.angularInit = angularInit;
//# sourceMappingURL=init.js.map